# sb::Data::Entry
# == Author(s) : Takuya Otani <takuya.otani@gmail.com> ==
# == Copyright (C) 2004 SimpleBoxes/SerendipityNZ Ltd. ==

# ======================================
package sb::Data::User;
use strict;
use sb::Data::Object ();
use base qw( sb::Data::Object );
use vars qw( $VERSION );
$VERSION = '0.09';
# 0.09 [2007/12/07] added imagetag option to edit / modified default option
# 0.08 [2007/09/16] changed table, field "ext" should be 'text'
# 0.07 [2007/08/04] added initializer
# 0.06 [2007/07/16] changed return to make them consistent
# 0.05 [2007/02/11] added formatted_profile
# 0.04 [2006/07/01] ported from biscuit
# 0.03 [2005/07/25] added cat_open option to edit
# 0.02 [2005/07/22] changed data structure to array
# 0.01 [2005/02/03] added auto_cat option to edit
# 0.00 [2005/02/02] generated
# --------------------------------------
# // defines / static variables
my %aOptionKeys = (
	'status'    => 0,  # default status (unused)
	'format'    => 1,  # default text format
	'init_date' => 2,  # updating date option
	'comment'   => 3,  # default status for comments
	'trackback' => 4,  # default status for trackbacks
	'ping'      => 5,  # default status for update ping
	'sequel'    => 6,  # using "sequel" option
	'summary'   => 7,  # using "summary" option (unsed)
	'imagelist' => 8,  # image selector option
	'imagemax'  => 9,  # max number of image selector
	'advanced'  => 10, # advanced settings
	'tb_option' => 11, # trackback option
	'edit_tool' => 12, # tool icon settings
	'auto_cat'  => 13, # additional category option
	'cat_open'  => 14, # additional category form option
	'imagetag'  => 15, # image tag insertion option when an image is uploaded
);
sub DEFAULT_OPTION  (){ '1:1:0:1:1:1:0:0:3:10:0:0:0000000001111111111111111111:0:0:0:' };
sub DEFALT_TOOLICON (){ "strong:strong\nem:em\np:p\nblockquote:quote\nul:ul\nli:li\np[class=&quot;note&quot;]:cust1\n:cust2\n:cust3\nhr[/]:hr\nol:ol\ndl:dl\ndt:dt\ndd:dd\ndel:del\nins:ins\nh3:h3\nh4:h4\ntable:table\ntr:tr\nth:th\ntd:td\ndiv[style=&quot;text-align&#58;left&quot;]:left\ndiv[style=&quot;text-align&#58;center&quot;]:center\ndiv[style=&quot;text-align&#58;right&quot;]:right" };
# --------------------------------------
# // override base class - table
sub table
{
	my $self = shift;
	return (
		'id'     => 'uni_id',   # id
		'wid'    => 'id',       # weblog id (reserved)
		'name'   => 'str(32)',  # account name
		'pass'   => 'str(255)', # password
		'real'   => 'str(255)', # display name
		'disp'   => 'int',      # status for user list
		'mail'   => 'str(255)', # mail address
		'notice' => 'int',      # notification option
		'stat'   => 'int',      # administration level
		'order'  => 'int',      # order of list
		'prof'   => 'text',     # profile description
		'aws'    => 'str(255)', # amazon assosiate id
		'edit'   => 'str(255)', # setting for edit
		'ext'    => 'text',     # setting for tool icons
		'info'   => 'str(255)', # information (reserved)
		'img'    => 'str(255)', # image (reserved)
		'friend' => 'text',     # friend (reserved)
		'cat'    => 'int',      # default category
		'form'   => 'str(255)', # profile format
		'ad_css' => 'str(255)', # style for manager script
	);
}
# --------------------------------------
# // initializer
BEGIN
{
	__PACKAGE__->init_accessor();
}
sub default
{ # default settings
	my $self  = shift;
	my %param = @_;
	$param{'wid'} |= 0;
	$param{'edit'} |= DEFAULT_OPTION;
	$param{'ext'} |= DEFALT_TOOLICON;
	$param{'stat'} = 2 if ($param{'stat'} eq '');
	$param{'order'} = $self->id;
	$self->SUPER::initialize(%param);
}
# --------------------------------------
# // public functions
sub real
{
	my $self = shift;
	$self->{'real'} = shift if @_;
	return ($self->{'real'} ne '') ? $self->{'real'} : $self->{'name'};
}
sub pass
{
	my $self = shift;
	if ( @_ )
	{
		my $pass = shift;
		my $salt = '';
		my @tmps = ('a'..'z','A'..'Z','0'..'9','.','/');
		1 while ( length($salt .= $tmps[rand(@tmps)]) < 8 );
		$salt = '$1$' . $salt . '$' if (index(crypt('a','$1$a$'),'$1$a$') == 0);
		$self->{'pass'} = crypt($pass,$salt);
	}
	return $self->{'pass'};
}
sub set_option
{
	my $self = shift;
	my $key   = shift;
	my $value = shift;
	return if (!$key);
	return if (! defined($aOptionKeys{$key}));
	my @option = split(':',$self->edit);
	$option[$aOptionKeys{$key}] = $value;
	$self->edit(join(':',@option) . ':');
	return;
}
sub get_option
{
	my $self = shift;
	my $key  = shift;
	my @option = split(':',$self->edit);
	return $option[$aOptionKeys{$key}];
}
sub get_option_keys
{
	my $self = shift;
	return keys(%aOptionKeys);
}
sub check_pass
{
	my $self = shift;
	my $input = shift;
	return (crypt($input,$self->{'pass'}) eq $self->{'pass'});
}
sub formatted_profile
{
	my $self = shift;
	return sb::Text->new($self->prof)->format($self->form,$self);
}
# --------------------------------------
# // private functions
1;
__END__
